@@ -6,10 +6,10 @@ use crate::flags::Flags;
 use crate::ops;
 use crate::proc_state::ProcState;
 use crate::version;
-use deno_core::error::anyhow;
+use deno_core::anyhow::anyhow;
+use deno_core::anyhow::Context;
 use deno_core::error::type_error;
 use deno_core::error::AnyError;
-use deno_core::error::Context;
 use deno_core::futures::FutureExt;
 use deno_core::located_script_name;
 use deno_core::resolve_url;
