@@ -302,7 +302,7 @@ unitTest(async function bufferReadFrom() {
     const fub = new Uint8Array(testString.length);
     await empty(b, s, fub);
   }
-  assertRejects(async function () {
+  await assertRejects(async function () {
     await new Deno.Buffer().readFrom(null!);
   });
 });
